@@ -52,7 +52,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "chrome101",
@@ -101,7 +102,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "chrome104",
@@ -150,7 +152,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "chrome107",
@@ -199,7 +202,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "chrome110",
@@ -249,7 +253,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "chrome116",
@@ -299,7 +304,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "chrome119",
@@ -346,11 +352,12 @@ const struct impersonate_opts impersonations[] = {
     .http2_window_update = 15663105,
     .http2_stream_weight = 256,
     .http2_stream_exclusive = 1,
-    .ech = "grease",
+    .ech = "true",
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "chrome120",
@@ -397,11 +404,12 @@ const struct impersonate_opts impersonations[] = {
     .http2_window_update = 15663105,
     .http2_stream_weight = 256,
     .http2_stream_exclusive = 1,
-    .ech = "grease",
+    .ech = "true",
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "chrome123",
@@ -448,11 +456,12 @@ const struct impersonate_opts impersonations[] = {
     .http2_window_update = 15663105,
     .http2_stream_weight = 256,
     .http2_stream_exclusive = 1,
-    .ech = "grease",
+    .ech = "true",
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "chrome124",
@@ -501,11 +510,12 @@ const struct impersonate_opts impersonations[] = {
     .http2_window_update = 15663105,
     .http2_stream_weight = 256,
     .http2_stream_exclusive = 1,
-    .ech = "grease",
+    .ech = "true",
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "chrome131",
@@ -554,11 +564,12 @@ const struct impersonate_opts impersonations[] = {
     .http2_window_update = 15663105,
     .http2_stream_weight = 256,
     .http2_stream_exclusive = 1,
-    .ech = "grease",
+    .ech = "true",
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "chrome131_android",
@@ -607,11 +618,12 @@ const struct impersonate_opts impersonations[] = {
     .http2_window_update = 15663105,
     .http2_stream_weight = 256,
     .http2_stream_exclusive = 1,
-    .ech = "grease",
+    .ech = "true",
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "chrome133a",
@@ -660,11 +672,12 @@ const struct impersonate_opts impersonations[] = {
     .http2_window_update = 15663105,
     .http2_stream_weight = 256,
     .http2_stream_exclusive = 1,
-    .ech = "grease",
+    .ech = "true",
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = true,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "chrome136",
@@ -713,11 +726,12 @@ const struct impersonate_opts impersonations[] = {
     .http2_window_update = 15663105,
     .http2_stream_weight = 256,
     .http2_stream_exclusive = 1,
-    .ech = "grease",
+    .ech = "true",
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = true,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "chrome142",
@@ -766,11 +780,12 @@ const struct impersonate_opts impersonations[] = {
     .http2_window_update = 15663105,
     .http2_stream_weight = 256,
     .http2_stream_exclusive = 1,
-    .ech = "grease",
+    .ech = "true",
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = true,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "chrome99",
@@ -819,7 +834,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "chrome99_android",
@@ -868,7 +884,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "edge101",
@@ -917,7 +934,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "edge99",
@@ -966,7 +984,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "firefox133",
@@ -1022,7 +1041,7 @@ const struct impersonate_opts impersonations[] = {
     .http2_pseudo_headers_order = "mpas",
     .http2_stream_exclusive = 0,
     .cert_compression = "zlib,brotli,zstd",
-    .ech = "grease",
+    .ech = "true",
     .tls_session_ticket = true,
     .tls_extension_order = "0-23-65281-10-11-35-16-5-34-51-43-13-45-28-27-65037",
     .tls_delegated_credentials = "ecdsa_secp256r1_sha256:ecdsa_secp384r1_sha384:ecdsa_secp521r1_sha512:ecdsa_sha1",
@@ -1030,6 +1049,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_grease = false,
     .tls_signed_cert_timestamps = false,
     .tls_key_shares_limit = 3,
+    .split_cookies = true,
   },
   {
     .target = "firefox135",
@@ -1086,7 +1106,7 @@ const struct impersonate_opts impersonations[] = {
     .http2_pseudo_headers_order = "mpas",
     .http2_stream_exclusive = 0,
     .cert_compression = "zlib,brotli,zstd",
-    .ech = "grease",
+    .ech = "true",
     .tls_session_ticket = true,
     .tls_extension_order = "0-23-65281-10-11-35-16-5-34-18-51-43-13-45-28-27-65037",
     .tls_delegated_credentials = "ecdsa_secp256r1_sha256:ecdsa_secp384r1_sha384:ecdsa_secp521r1_sha512:ecdsa_sha1",
@@ -1094,6 +1114,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_grease = false,
     .tls_signed_cert_timestamps = true,
     .tls_key_shares_limit = 3,
+    .split_cookies = true,
   },
   {
     .target = "firefox144",
@@ -1151,7 +1172,7 @@ const struct impersonate_opts impersonations[] = {
     .http2_stream_exclusive = 0,
     .http2_stream_weight = 42,
     .cert_compression = "zlib,brotli,zstd",
-    .ech = "grease",
+    .ech = "true",
     .tls_session_ticket = true,
     .tls_extension_order = "0-23-65281-10-11-35-16-5-34-18-51-43-13-45-28-27-65037",
     .tls_delegated_credentials = "ecdsa_secp256r1_sha256:ecdsa_secp384r1_sha384:ecdsa_secp521r1_sha512:ecdsa_sha1",
@@ -1159,6 +1180,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_grease = false,
     .tls_signed_cert_timestamps = true,
     .tls_key_shares_limit = 3,
+    .split_cookies = true,
   },
   {
     .target = "okhttp4_android",
@@ -1220,7 +1242,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "safari153",
@@ -1285,7 +1308,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "safari155",
@@ -1345,7 +1369,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "safari170",
@@ -1408,7 +1433,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "safari172_ios",
@@ -1471,7 +1497,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "safari180",
@@ -1534,7 +1561,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "safari180_ios",
@@ -1597,7 +1625,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "safari184",
@@ -1660,7 +1689,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "safari184_ios",
@@ -1723,7 +1753,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "safari260",
@@ -1785,7 +1816,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "safari2601",
@@ -1847,7 +1879,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "safari260_ios",
@@ -1909,7 +1942,8 @@ const struct impersonate_opts impersonations[] = {
     .tls_extension_order = NULL,
     .tls_use_new_alps_codepoint = false,
     .tls_signed_cert_timestamps = true,
-    .tls_grease = true
+    .tls_grease = true,
+    .split_cookies = true,
   },
   {
     .target = "tor145",  // tor 14.5, based on firefox 128
@@ -1965,7 +1999,7 @@ const struct impersonate_opts impersonations[] = {
     .http2_pseudo_headers_order = "mpas",
     .http2_stream_exclusive = 0,
     .cert_compression = "zlib,brotli,zstd",
-    .ech = "grease",
+    .ech = "true",
     .tls_session_ticket = true,
     .tls_extension_order = "0-23-65281-10-11-16-5-34-51-43-13-28-65037",
     .tls_delegated_credentials = "ecdsa_secp256r1_sha256:ecdsa_secp384r1_sha384:ecdsa_secp521r1_sha512:ecdsa_sha1",
@@ -1973,6 +2007,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_grease = false,
     .tls_signed_cert_timestamps = true,
     .tls_key_shares_limit = 2,
+    .split_cookies = true,
   }
 };
 
